package org.jenkinsci.plugins.p4.groovy;

import java.io.File;
import java.io.IOException;
import java.io.Serializable;

import org.jenkinsci.plugins.p4.client.ClientHelper;
import org.jenkinsci.plugins.p4.workspace.Workspace;
import org.jenkinsci.remoting.RoleChecker;
import org.jenkinsci.remoting.RoleSensitive;

import hudson.FilePath.FileCallable;
import hudson.model.TaskListener;
import hudson.remoting.VirtualChannel;
import jenkins.security.Roles;

public class GetP4Task implements FileCallable<P4Groovy>, Serializable {

	private static final long serialVersionUID = 1L;

	private final String credential;
	private final Workspace workspace;
	private final String client;
	private final String charset;

	private TaskListener listener;

	public GetP4Task(String credential, Workspace workspace) {
		this.credential = credential;
		this.workspace = workspace;
		this.client = workspace.getFullName();
		this.charset = workspace.getCharset();
	}

	public void setListener(TaskListener listener) {
		this.listener = listener;
	}

	@Override
	public P4Groovy invoke(File buildWorkspace, VirtualChannel channel) throws IOException, InterruptedException {

		ClientHelper p4 = new ClientHelper(credential, listener, client, charset);
		try {
			p4.setClient(workspace);
		} catch (Exception e) {
			p4.log("Unable to set Client!");
		}
		P4Groovy p4Groovy = new P4Groovy(p4);
		return p4Groovy;
	}

	@Override
	public void checkRoles(RoleChecker checker) throws SecurityException {
		checker.check((RoleSensitive) this, Roles.SLAVE);
	}
}
